Documentation
¶
Index ¶
- func Base64Decode(str string) ([]byte, error)
- func Base64Encode(str string) string
- func GetCurrentTimeStr() string
- func GetDayRange(start string, end string, format string) ([]string, error)
- func GetRandInt() int
- func GetRandInt32() int32
- func GetRanddomString(num int) string
- func GetResidueRandom(num int) int
- func IsAbsolutePath(path string) bool
- func IsDirExists(path string) bool
- func IsFileExist(path string) bool
- func ListDirFiles(dirPath string, suffix string) (interface{}, error)
- func Md5(str string) string
- func SubStr(str string, start int, end int) string
- func SubStrByOffset(str string, start int, offset int) string
- type Info
- type Item
- type Statistics
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Base64Decode ¶
func Base64Encode ¶
func GetCurrentTimeStr ¶
func GetCurrentTimeStr() string
GetCurrentTimeStr is used to get current time str with format "2006-01-02 15:04:05"
func GetDayRange ¶
GetDayRange is used to get a range of start and end time start string eg:2017-01-02 end string eg:2017-01-22 format string eg: 2006-01-02 result: ["2017-01-02","2017-01-03",...,"2017-01-21"]
func GetRandInt ¶
func GetRandInt() int
func GetRandInt32 ¶
func GetRandInt32() int32
func GetRanddomString ¶
func GetResidueRandom ¶
func IsAbsolutePath ¶
IsAbsolutePath is used to check path is absolute path
func IsDirExists ¶
IsDirExists is used to check dir is exist or not
func IsFileExist ¶
IsFileExist is used to check file exist or not
func ListDirFiles ¶
ListDirFiles is used to get all files in one path map[string]interface{}
Types ¶
type Statistics ¶
type Statistics struct {
// contains filtered or unexported fields
}
func NewStatistics ¶
func (*Statistics) AddItem ¶
func (s *Statistics) AddItem(item Item)
func (*Statistics) GetInfoByType ¶
func (s *Statistics) GetInfoByType(typeStr string) interface{}
func (*Statistics) GetInfoByTypeAndSubType ¶
func (s *Statistics) GetInfoByTypeAndSubType(typeStr string, subType string) interface{}
Click to show internal directories.
Click to hide internal directories.